@@ -1,15 +1,13 @@
-# pylint: disable=missing-class-docstring, missing-function-docstring
 import dataclasses
 import operator
-
 from typing import List
 
 import pytest
 
 from jsonpath import JSONPathEnvironment
-
-from jsonpath.token import Token
+from jsonpath.exceptions import JSONPathSyntaxError
 from jsonpath.token import TOKEN_AND
+from jsonpath.token import TOKEN_BARE_PROPERTY
 from jsonpath.token import TOKEN_COMMA
 from jsonpath.token import TOKEN_DDOT
 from jsonpath.token import TOKEN_EQ
@@ -23,7 +21,6 @@ from jsonpath.token import TOKEN_INDEX
 from jsonpath.token import TOKEN_INT
 from jsonpath.token import TOKEN_INTERSECTION
 from jsonpath.token import TOKEN_LIST_END
-from jsonpath.token import TOKEN_BARE_PROPERTY
 from jsonpath.token import TOKEN_LIST_START
 from jsonpath.token import TOKEN_LT
 from jsonpath.token import TOKEN_NIL
@@ -42,6 +39,7 @@ from jsonpath.token import TOKEN_STRING
 from jsonpath.token import TOKEN_TRUE
 from jsonpath.token import TOKEN_UNION
 from jsonpath.token import TOKEN_WILD
+from jsonpath.token import Token
 
 
 @dataclasses.dataclass
@@ -1045,13 +1043,17 @@ TEST_CASES = [
 ]
 
 
-@pytest.fixture
+@pytest.fixture()
 def env() -> JSONPathEnvironment:
     return JSONPathEnvironment()
 
 
-# pylint: disable=redefined-outer-name
 @pytest.mark.parametrize("case", TEST_CASES, ids=operator.attrgetter("description"))
 def test_default_lexer(env: JSONPathEnvironment, case: Case) -> None:
     tokens = list(env.lexer.tokenize(case.path))
     assert tokens == case.want
+
+
+def test_illegal_token(env: JSONPathEnvironment) -> None:
+    with pytest.raises(JSONPathSyntaxError):
+        list(env.lexer.tokenize("^"))
